@@ -1,5 +1,5 @@
 package Box::Calc;
-$Box::Calc::VERSION = '1.0001';
+$Box::Calc::VERSION = '1.0100';
 use strict;
 use Moose;
 use Box::Calc::BoxType;
@@ -16,7 +16,7 @@ Box::Calc - Packing Algorithm
 
 =head1 VERSION
 
-version 1.0001
+version 1.0100
 
 =head1 SYNOPSIS
 
@@ -92,8 +92,6 @@ Repeat from step 3 until all items are packed into boxes.
 
 =back
 
-=back
-
 =head2 Motivation
 
 At The Game Crafter (L<http://www.thegamecrafter.com>) we ship a lot of games and game pieces. We tried using a more complicated system for figuring out which size box to use, or how many boxes would be needed in a spanning situation. The problem was that those algorithms made the boxes pack so tightly that our staff spent a lot more time putting the boxes together. This algorithm is relatively dumb, but dumb in a good way. The boxes are easy and fast to pack. By releasing this, we hope it can help those who are either using too complicated a system, or no system at all for figuring out how many boxes they need for shipping/storing materials. 
@@ -205,7 +203,7 @@ has box_type_categories => (
             next if $box_type->category eq '';
             $categories{$box_type->category} = 1;
         }
-        return [keys %categories];
+        return [sort keys %categories];
     },
 );
 
@@ -426,6 +424,33 @@ sub sort_items_by_zxy {
     return \@sorted;
 }
 
+=head2 sort_items_by_z_desc_A()
+
+Returns an array reference of the list of C<items> registered sorted by z DESC, then area DESC
+
+=over
+
+=item items
+
+Optional. An array reference of items. Will call C<items> if not passed in.
+
+=back
+
+=cut
+
+sub sort_items_by_z_desc_A {
+    my $self = shift;
+    my $items = shift || $self->items;
+    my @sorted = map  { $_->[1] }
+                 sort {
+                    $b->[0]->{z} <=> $a->[0]->{z}
+                 || $b->[0]->{A} <=> $a->[0]->{A}
+                 }
+                 ##Fetch Z and calculate A
+                 map  { [ { z=>$_->z, A=>$_->x*$_->y }, $_ ] } @{$items};
+    return \@sorted;
+}
+
 =head2 sort_items_by_zA()
 
 Returns an array reference of the list of C<items> registered sorted by z ASC, then area DESC
